# Data API Reference

# Context & Lifecycle

::: aaiclick.data.data_context.data_context

::: aaiclick.data.data_context.create_object

::: aaiclick.data.data_context.create_object_from_value

::: aaiclick.data.data_context.open_object

::: aaiclick.data.data_context.delete_object

::: aaiclick.data.data_context.delete_persistent_object

::: aaiclick.data.data_context.delete_persistent_objects

::: aaiclick.data.data_context.list_persistent_objects

# Object

::: aaiclick.data.object.Object

# View

::: aaiclick.data.object.View

# Data Results

::: aaiclick.data.object.DataResult

# URL Loading

::: aaiclick.data.object.url.create_object_from_url

# Snowflake IDs

::: aaiclick.snowflake_id.get_snowflake_id

::: aaiclick.snowflake_id.get_snowflake_ids
